@@ -23,11 +23,11 @@ AnyEvent::Connection - Base class for tcp connectful clients
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 =head1 SYNOPSIS
@@ -280,7 +280,7 @@ sub connect {
 }
 
 sub accept {
-	croak "TODO";
+	croak "Not implemented yet";
 }
 
 
